@@ -115,20 +115,36 @@ extract2_tbstat <- function(x, ...)
 #'
 #' A set of helper functions for \code{\link{tableby}}.
 #'
-#' @param object A \code{data.frame} resulting form evaluating \code{modelsum} formula.
+#' @param object A \code{data.frame} resulting from evaluating a \code{tableby} formula.
 #' @param ... Other arguments, or a vector of indices for extracting.
 #' @param x,y A \code{tableby} object.
 #' @param i A vector to index \code{x} with: either names of variables, a numeric vector, or a logical vector of appropriate length.
 #' @param value A list of new labels.
 #' @param pdata A named data.frame where the first column is the x variable names matched by name, the second is the
 #'   p-values (or some test stat), and the third column is the method name (optional)
+#' @param e1,e2 \code{\link{tableby}} objects, or numbers to compare them to.
 #' @param use.pname Logical, denoting whether the column name in \code{pdata} corresponding to the p-values should be used
 #'   in the output of the object.
-#' @return \code{na.tableby} returns a subsetted version of \code{object} (with attributes).
+#' @return \code{na.tableby} returns a subsetted version of \code{object} (with attributes). \code{Ops.tableby} returns
+#'   a logical vector. \code{xtfrm.tableby} returns the p-values (which are ordered by \code{\link{order}} to \code{\link{sort}}).
+#' @details
+#' Logical comparisons are implemented for \code{Ops.tableby}.
+#'
+#' \code{xtfrm.tableby} also allows the use of \code{\link{order}} and \code{\link{sort}}.
+#'
+#' \code{length.tableby} also allows for the use of \code{\link[utils]{head}} and \code{\link[utils]{tail}}.
 #' @name tableby.internal
 NULL
 #> NULL
 
+#' @rdname tableby.internal
+#' @export
+is.tableby <- function(x) inherits(x, "tableby")
+
+#' @rdname tableby.internal
+#' @export
+is.summary.tableby <- function(x) inherits(x, "summary.tableby")
+
 #' @rdname tableby.internal
 #' @export
 merge.tableby <- function(x, y, ...) {
@@ -332,13 +348,37 @@ tests.tableby <- function(x) {
 #' @rdname tableby.internal
 #' @export
 na.tableby <- function(object, ...) {
-    omit <- is.na(object[,1])
+    omit <- is.na(object[[1]])
     xx <- object[!omit, , drop = FALSE]
-    if(any(omit > 0L)) {
-        temp <- stats::setNames(seq(omit)[omit], attr(object, "row.names")[omit])
+    if(any(omit)) {
+        temp <- stats::setNames(seq_along(omit)[omit], attr(object, "row.names")[omit])
         attr(temp, "class") <- "omit"
         attr(xx, "na.action") <- temp
     }
     xx
 }
 
+
+#' @rdname tableby.internal
+#' @export
+xtfrm.tableby <- function(x)
+{
+  if(!x$control$test) stop("Can't extract p-values from a tableby object created with test=FALSE.")
+  vapply(x$x, function(lst) lst$test$p.value, NA_real_)
+}
+
+#' @rdname tableby.internal
+#' @export
+Ops.tableby <- function(e1, e2)
+{
+  ok <- switch(.Generic, `<` = , `>` = , `<=` = , `>=` = , `==` = , `!=` = TRUE, FALSE)
+  if(!ok) stop("'", .Generic, "' is not meaningful for tableby objects")
+
+  if(inherits(e1, "tableby")) e1 <- xtfrm(e1)
+  if(inherits(e2, "tableby")) e2 <- xtfrm(e2)
+  get(.Generic, mode = "function")(e1, e2)
+}
+
+#' @rdname tableby.internal
+#' @export
+length.tableby <- function(x) length(x$x)
